.\" bm# 0000002249
.\" typ N
.\" ver generic
.\" mod generic
.\"
.\"     SCCSID(@(#)lex.CP	1.1);


.ds mc 
.ds rv Revision 1
.TH LEX CP
.SH Name
lex \- Generates programs for lexical analysis.
.SH Syntax
.B lex
.RB [ \-ctvn ] 
[ file ] ...
.SH Description
.I Lex\^
generates programs to be used in simple lexical analysis of text.
A file 
.B lex.yy.c
is generated which, when loaded
with the 
.I lex
library, copies the input to the output
except when a string specified in the file is found. If
a string is found,
the corresponding program text is executed.
.PP
The input
.I file\^
contains strings and expressions
to be searched for, and C text to be executed when
strings are found.  Multiple files are treated as a single file.
If no files are specified,
standard input is used.
.PP
The options must appear before any files.  The
options are as follows:
.TP 8
.B \-c
Indicates C actions and is the default.
.TP
.B \-t
Causes the
.B lex.yy.c
program to be written instead to standard output.
.TP
.B \-v
Provides a one-line summary of statistics of the machine generated.
.TP
.B \-n
Suppresses the
.BR \- " summary."
.SH "Strings and Operators"
.B Lex
strings
may contain square brackets to indicate character classes,
as in
.B [abx\-z]
to indicate
.BR a , " b" , " x" ,
.BR y ", and " z ;
and the operators
.BR \(** ", " + ", and " ?
mean respectively
any nonnegative number of, any positive number of, and either
zero or one occurrences of, the previous character or character class.
Thus,
.B [a-zA-Z]+
matches a string of letters.
The character
.B .
is the class of all
.SM ASCII
characters except newline.
Parentheses for grouping and vertical bar for alternation are
also supported.
The notation
.IB r { d , e }
in a rule indicates between
.I d\^
and
.I e\^
instances of regular expression
.IR r .
It has higher precedence than
.IR | ,
but lower than
.IR \(** ,
.IR ? ,
.IR + ,
and concatenation.
The character
.B ^
at the beginning of an expression
permits a
successful match only immediately after a newline, and the character
.B $
at the end of an expression requires a trailing newline.
The character
.B /
in an expression indicates trailing context;
only the part of the expression up to the slash
is returned in
.IR yytext ,
but the remainder of the expression must follow in the input stream.
An operator character may be used as an ordinary symbol
if it is within \fB"\fR
symbols or preceded by
.BR \e .
.SH "Routines and Variables"
Matching is done in order of the strings in the file.
The actual string matched is left in
.IR yytext ,
an external character array.
Three subroutines defined as macros are expected:
.B input()
to read a character;
.BI unput( c )
to replace a character read; and
.BI output( c )
to place
an output character.  They are defined in terms
of the standard streams,
but you can override them.
The program generated is named
.BR yylex() ,
and the library contains a
.B main()
which calls it.
The action
.SM REJECT
on the right side of the rule causes this
match to be rejected and the next suitable match executed;
the function
.B yymore()
accumulates additional characters
into the same
.IR yytext ;
and the function
.BI yyless( p )
pushes
back the portion of the string matched beginning at
.IR p ,
which
should be between
.I yytext\^
and
.IR yytext + yyleng .
The macros
.I input\^
and
.I output\^
use files
.B yyin
and
.B yyout
to read from and write to,
defaulted to
.B stdin
and
.BR stdout ,
respectively.
The external names generated by
.I lex\^
all begin with the prefix
.BR yy " or " YY .
.SH "Lex File Format"
Any line beginning with a blank is assumed
to contain only C text and is copied; if it precedes
.B %%
it is copied into the external definition area of the
.B lex.yy.c
file.
All rules should follow a
.BR %% ,
as in
.SM YACC.
Lines preceding
.B %%
which begin with a nonblank character define
the string on the left to be the remainder of
the line; it can be called out later by surrounding it with
.BR {} .
Note that curly brackets do not imply parentheses;
only string substitution is done.
.PP
Certain table sizes for the resulting finite state machine
can be set in the definitions section:
.RS
.TP "@.TP
.BI %p " n\^"
number of positions is
.I n\^
(default 2000)
.ns
.TP
.BI %n " n\^"
number of states is
.I n\^
(500)
.ns
.TP
.BI %t " n\^"
number of parse tree nodes is
.I n\^
(1000)
.ns
.TP
.BI %a " n\^"
number of transitions is
.I n\^
(3000)
.RE
.PP
The use of one or more of the above automatically implies the
.B \-v
option,
unless the
.B \-n
option is used.
.SH Example
.ta +8n +8n +8n +8n
.nf
	D	[0\-9]
	%%
	if	printf("\s-1IF\s+1 statement\\n");
	[a\-z]+	printf("tag, value %s\\n",yytext);
	0{D}+	printf("octal number %s\\n",yytext);
	{D}+	printf("decimal number %s\\n",yytext);
	"++"	printf("unary op\\n");
	"+"	printf("binary op\\n");
	"/\(**"	{	loop:
			while (input() != \(fm\(**\(fm);
			switch (input())
				{
				case \(fm/\(fm: break;
				case \(fm\(**\(fm: unput(\(fm\(**\(fm);
				default: go to loop;
				}
			}
.fi
.SH "See Also"
yacc(CP)
.br
.SM XENIX
.I "Programmer's Guide"
.SH Notes
This program translates its input into C source code,
which in segmented programming environments, 
is suitable for compiling as a small model program
only (see
.IR cc (CP)).
