.\" bm# 0000002054
.\" typ N
.\" ver generic
.\" mod generic
.\"
.\"     SCCSID(@(#)filesystem.F	1.1);


.ds mc 
.ds rv Revision 1
.TH FILESYSTEM F
.SH Name
file system \- Format of a system volume.
.SH Syntax
.B #include <sys/filsys.h>
.br
.B #include <sys/types.h>
.br
.B #include <sys/param.h>
.SH Description
Every file system storage volume
(e.g., a hard disk)
has a common format for certain vital information.
Every such volume is divided into a certain number
of 256 word (512 byte) blocks.
Block 0 is unused and is available to contain
a bootstrap program or other information.
.PP
Block 1 is the
.IR super-block .
The format of a super-block is described in
.BR /usr/include/sys/filesys.h .
In that include file,
.I S_isize\^
is the address of the first data block after the i-list.
The i-list starts just after the super-block in block 2;
thus the i-list is 
.IR s_isize \-2 
blocks long.
.I S_fsize\^
is the first block not potentially available for allocation to a file.
These numbers are used by the system to
check for bad block numbers.
If an ``impossible'' block number is 
allocated from the free list or is freed,
a diagnostic is written on the console.
Moreover, the free array is cleared so as to prevent further
allocation from a presumably corrupted free list.
.PP
The free list for each volume is maintained as
follows.
The
.I s_free\^
array contains, in
.IR s_free [1],
\&.\|.\|.,
.IR s_free [ s_nfree \-1],
up to 49 numbers of free blocks.
.IR S_free [0]
is the block number of the head
of a chain of blocks constituting the free list.
The first long in each free-chain block is the number
(up to 50) of free-block numbers listed in the
next 50 longs of this chain member.
The first of these 50 blocks is the link to the
next member of the chain.
To allocate a block:
decrement
.IR s_nfree ,
and the new block is
.IR s_free [ s_nfree ].
If the new block number is 0,
there are no blocks left, so give an error.
If
.I s_nfree\^
becomes 0,
read in the block named by the new block number,
replace
.I s_nfree\^
by its first word,
and copy the block numbers in the next 50 longs into the
.I s_free\^
array.
To free a block, check if
.I s_nfree\^
is 50; if so,
copy
.I s_nfree\^
and the
.I s_free\^
array into it,
write it out, and set
.I s_nfree\^
to 0.
In any event set
.IR s_free [ s_nfree ]
to the freed block's number and
increment
.IR s_nfree .
.PP
.I S_tfree\^
is the total free blocks available in the file system.
.PP
.I S_ninode\^
is the number of free i-numbers in the
.I s_inode\^
array.
To allocate an inode:
if
.I s_ninode\^
is greater than 0,
decrement it and return
.IR s_inode [ s_ninode ].
If it was 0, read the i-list
and place the numbers of all free inodes
(up to 100) into the
.I s_inode\^
array,
then try again.
To free an inode,
provided
.I s_ninode\^
is less than 100,
place its number into
.IR s_inode [ s_ninode ]
and increment
.IR s_ninode .
If
.I s_ninode\^
is already 100, do not bother to enter the freed inode into any table.
This list of inodes only speeds
up the allocation process. 
The information about
whether the inode is really free
is maintained in the inode itself.
.PP
.I S_tinode\^
is the total free inodes available in the file system.
.PP
.I S_flock\^
and
.I s_ilock\^
are flags maintained in the core
copy of the file system
while it is mounted
and their values on disk are immaterial.
The value of
.I s_fmod\^
on disk is also immaterial,
and is used as a flag to indicate that the super-block has
changed and should be copied to
the disk during the next periodic update of file
system information.
.PP
.I S_ronly\^
is a read-only flag to indicate write-protection.
.PP
.I S_time\^
is the last time the super-block of the file system was changed,
and is a double-precision representation
of the number of seconds that have elapsed
since
00:00 Jan. 1, 1970 (\s-1GMT\s+1).
During a reboot, the
.I s_time\^
of the super-block for the root file system
is used to set the system's idea of the time.
'\"	.PP
'\"	.I S_fname\^
'\"	is the name of the file system and
'\"	.I s_fpack\^
'\"	is the name of the pack.
.PP
I-numbers begin at 1, and the storage for inodes
begins in block 2.
Also, inodes are 64 bytes long, so 8 of them fit into a block.
Therefore, inode
.I i\^
is located in block (\fIi\^\fR+15)/8, and begins
64\(mu((\fIi\^\fR+15)\ (mod 8))
bytes from its start.
Inode 1 is reserved for future use.
Inode 2 is reserved for the root directory of the file
system, but no other i-number has a built-in
meaning.
Each inode represents one file.
For the format of an inode and its flags, see
.IR inode (F).
.SH Files
/usr/include/sys/filsys.h
.sp
/usr/include/sys/stat.h
.SH "See Also"
fsck(C), mkfs(C), inode(F)
