.\" bm# 0000002300
.\" typ N
.\" ver generic
.\" mod generic
.\"
.\"     SCCSID(@(#)messages.M	1.1);


.ds mc 
.ds rv Revision 1
.TH MESSAGES M
.SH Name
messages \- Description of system console messages.
.SH Description
This section describes the various system messages 
which may appear on the system console.  These
messages are divided into three groups: messages
which are common to all versions of 
.SM XENIX ,
messages which are specific to the 286 version of 
.SM XENIX ,
and messages which apply to the devices.
.PP
Most of the system messages begin with ``panic:'' and are
fatal (the system refuses to execute further).  
Fatal messages represent hardware problems or kernel software
inconsistencies.  
Such internal inconsistencies are usually traceable
to hardware problems themselves, often forms of memory failure.
.PP
A few messages represent kernel operation problems, 
typically the overflow of a critical table.  
These potential problems are guarded
against by the kernel. 
It takes extreme situations to bring them
about, so they 
should never occur in normal system use.
.PP
The messages are categorized as follows:
.TP
.I Fatal
Recovery is impossible.
.TP
.I "System inconsistency"
A contradictory situation exists in the kernel.
.TP
.I Abnormal
A probably legitimate but extreme situation exists.
.TP
.I Hardware
Indicates a hardware problem.
.PP
Many of the following messages are accompanied 
by a device specification,
.I dev.
This will print as
.I nn/mm
where
.I nn
is the major number and
.I mm
is the minor number of the offending device.
If you do not recognize the device by its numbers type:
.sp 10p
.RS
ls -l /dev | grep
.I nn
| grep
.I mm
.RE
.PP
This will allow you to associate numbers with a
physical device.
.br
.ne 1i
.SS "Common System Messages"
.HP 5
bad block on dev \fInn\fP/\fImm\fP
.br
A nonexistent disk block was found on,
or is being inserted in, the structure's free list.
.I System inconsistency.
.HP 5
bad count on dev \fInn\fP/\fImm\fP
.br
A structural inconsistency in the superblock of a file system.  
The system attempts a repair, 
but this message will probably be followed by more
complaints about this file system.
.I System inconsistency.
.HP 5
Bad free count on dev \fInn\fP/\fImm\fP
.br
A structural inconsistency in the superblock of a file system.  
The system attempts a repair, 
but this message will probably be followed by more
complaints about this file system.
.I System inconsistency.
.HP 5
error on dev \fIname\fP (\fInn\fP/\fImm\fP)
.br
This is the way that most device driver diagnostic messages start.
The message will indicate the specific driver and complaint.
The 
.I name
is a word identifying the device.
.HP 5
Inode table overflow
.br
Each open file requires an inode entry to be kept in memory.  When
this table overflows the specific request (usually
.IR open (S)
or
.IR creat (S))
is refused.  
Although not fatal to the system, 
this event may damage the operation
of various spoolers, daemons, the mailer, 
and other important utilities.
Anomalous results and missing data files are a common result.  
.I Abnormal.
.HP 5
interrupt from unknown device, vec=\fIxxxx\fP
.br
The CPU received an interrupt via a supposedly unused vector.
This message is followed by ``Panic: unknown interrupt.''
Typically this event comes about when a hardware failure miscomputes
the vector of a valid interrupt.
.I Hardware.
.HP 5
no file
.br
There are too many open files, 
the system has run out of entries in its 
``open file'' table.  
The warnings given for the message 
``inode\ table\ overflow'' apply here.
.I Abnormal.
.HP 5
no space on dev \fInn\fP/\fImm\fP
.br
This message means that the specified file system
has run out of free blocks.
Although not normally as serious, the
warnings discussed for ``inode table overflow'' apply: 
often programs
are written casually and ignore the error code returned when they
tried to write to the disk; this results in missing data and ``holes''
in data files.  The system administrator should keep close watch on
the amount of free disk space and take steps to avoid this situation.
.HP 5
**  Normal System Shutdown  **
.br
This message appears when the system has been shutdown properly.
It indicates that the machine may now be rebooted or powered down.
.HP 5
Out of inodes on dev \fInn\fP/\fImm\fP
.br
The indicated file system has run out of free inodes.  
The number of
inodes available on a file system is determined when 
.IR mkfs (C)
is run.
The default number is quite generous, 
this message should be very rare.  
The only recourse is to remove some worthless files from that
file system, or dump the entire system to a backup device, rerun
.IR mkfs (C)
with more inodes specified, and restore the files from backup.
.HP 5
out of text
.br
When programs linked with the 
.I ld
.B \-i 
or 
.B \-n 
switch are run, a table
entry is made so that only one copy 
of the pure text will be in memory
even if there are multiple copies of the program running.  
This message
appears when this table is full.
The system refuses to run the program
which caused the overflow.
Note that there is only one entry in this
table for each different pure text program.
Multiple copies of one
program will not require multiple table entries.
Each ``sticky'' program
(see 
.IR chmod (C))
requires 
a permanent entry in this table; nonsticky
pure text programs require an entry only 
when there is at least one
copy being executed.
.HP 5
panic: blkdev
.br
An internal disk I/O request, already verified as valid, is discovered
to be refering to a nonexistent disk.
.I "System inconsistency, fatal."
.HP 5
panic: devtab
.br
An internal disk I/O request, already verified as valid, is discovered
to be refering to a nonexistent disk.
.I "System inconsistency, fatal."
.HP 5
panic: iaddress > 2^24
.br
This indicates an attempted reference to an illegal block number,
one so large that it could only occur 
on a file system larger than 8 billion bytes.
.I "System inconsistency, fatal."
.HP 5
panic: no fs
.br
A file system descriptor has disappeared from its table.
.I "System inconsistency, fatal."
.HP 5
panic: no imt
.br
A mounted file system has disappeared from the mount table.
.I "System inconsistency, fatal."
.HP 5
panic: no procs
.br
Each user is
limited in the amount of simultaneous processes he can have; 
an attempt to create a new process when none is available 
or when the user's limit is exceeded is refused.  
That is an occasional event and produces no
console messages; this panic occurs when the kernel has certified
that a free process table entry is available and 
yet can't find one when it goes to get it.
.I "System inconsistency, fatal."
.HP 5
panic: out of swap 
.br
There is insufficient space on the swap disk to hold a task.
The system refuses to create tasks when it feels there is insufficient
disk space, but it is possible to create situations to fool this
mechanism.
.I Abnormal, fatal.
.HP 5
panic: Timeout table overflow
.br
The timeout table is full.  
Timeout requests are generated by device
drivers, there should usually be room for one entry per system serial
line plus ten more for other usages.  
.HP 5
panic: Trap in sys
.br
The CPU has generated an illegal instruction trap while executing
kernel or device driver code.  
This message is preceded with
an information dump describing the trap.
.I "System inconsistency, fatal."
.HP 5
panic: unknown interrupt
.br
The CPU received an interrupt via a supposedly unused vector.
Typically this event comes about when a hardware failure miscomputes
the vector of a valid interrupt.
.I "Hardware, fatal."
'
.SS "286 Machine-Specific Messages"
'
.HP 5
panic: iinit
.br
The super-block of the root file system could not be read.  This
message occurs only at boot time.
.I "Hardware, fatal."
.HP 5
panic: IO err in swap
.br
A fatal I/O error occurred while reading or writing the swap area.
.I "Hardware, fatal."
.HP 5
panic: memory failure - parity error
.br
The internal memory management tables have become corrupted.
.I "System inconsistency, fatal."
