.\" bm# 0000002442
.\" typ N
.\" ver 68k.generic
.\" mod generic
.\"
.ds mc
.ds rv Revision 1
.TH INTRO S
.de {n
.HP
\\$1  \\$2  \\$3
.br
..
.SH Name
intro \- Introduces system services, library routines and error numbers.
.SH Syntax
.B #include \|<errno.h>
.SH Description
This section describes all system services.
System services include all routines or system calls that are
available in the operating system kernel. 
These routines are available to a C program automatically
as part of the standard library libc.
Other routines are available in a variety of libraries.
.P
To use routines in a program that are
not part of the standard library libc,
the appropriate library must be linked.
This is done by specifying
.RI \-l name
to the compiler or linker, where
.I name
is the name listed below less the
.I lib
prefix. For example
.B \-lm ,
and
.B \-ltermcap 
are specifications to the linker to search the named libraries
for routines to be linked to the object module.
Available libraries are listed below:
.P
.TP 15
libc
The standard library containing all system call interfaces,
Standard I/O routines, and other general purpose services.
.TP
libm
The standard math library.
.TP
libtermcap
Routines for accessing the
.I termcap
data base describing terminal characteristics.
.TP
libcurses
Screen and cursor manipulation routines.
.TP
libdbm
Data base management routines.
.LE
Most services that are part of the operating system kernel
have one or more error returns.
An error condition is indicated by an otherwise
impossible returned value.
This is almost always \-1;
the individual descriptions specify the details.
An error number is also made available
in the external variable
.IR errno .
.I Errno\^
is not cleared on successful calls, so it should be tested only
after an error has been indicated.
.PP
All of the possible error numbers
are not listed in each system call description because many
errors are possible for most of the calls.
The following is a complete list of the error numbers and
their names as defined in
.BR <error.h> .
.{n 1 \s-1EPERM\s+1 "Not owner"
Typically this error indicates
an attempt to modify a file in some way forbidden
except to its owner or super-user.
It is also returned for attempts
by ordinary users to do things
allowed only to the super-user.
.{n 2 \s-1ENOENT\s+1 "No such file or directory"
This error occurs when a filename is specified
and the file should exist but doesn't, or when one
of the directories in a pathname does not exist.
.{n 3 \s-1ESRCH\s+1 "No such process"
No process can be found corresponding to that specified by
.I pid\^
in
.I kill\^
or
.IR ptrace .
.{n 4 \s-1EINTR\s+1 "Interrupted system call"
An asynchronous signal (such as interrupt or quit),
which the user has elected to catch,
occurred during a system call.
If execution is resumed
after processing the signal,
it will appear as if the interrupted system call
returned this error condition.
.{n 5 \s-1EIO\s+1 "I/O error"
Some physical I/O error.
This error may in some cases occur
on a call following the one to which it actually applies.
.{n 6 \s-1ENXIO\s+1 "No such device or address"
I/O on a special file refers to a subdevice which does not
exist,
or beyond the limits of the device.
It may also occur when, for example, a tape drive
is not on-line or no disk pack is loaded on a drive.
.{n 7 \s-1E2BIG\s+1 "Arg list too long"
An argument list longer than 5,120 bytes
is presented to a member of the
.I exec\^
family.
.{n 8 \s-1ENOEXEC\s+1 "Exec format error"
A request is made to execute a file
which, although it has the appropriate permissions,
does not start with a valid magic number (see
.IR a.out (F)).
.{n 9 \s-1EBADF\s+1 "Bad file number"
Either a file descriptor refers to no
open file,
or a read (respectively write) request is made to
a file which is open only for writing (respectively reading).
.{n 10 \s-1ECHILD\s+1 "No child processes"
A
.IR wait ,
was executed by a process that had no existing or unwaited-for child processes.
.{n 11 \s-1EAGAIN\s+1 "No more processes"
A
.IR fork ,
failed because the system's process table is full
or the user is not allowed to create any more
processes.
.{n 12 \s-1ENOMEM\s+1 "Not enough space"
During an
.IR exec ,
'\".IR brk ,
or
.IR sbrk ,
a program asks for more space than the system is able to supply.
This is not a temporary condition; the maximum space size
is a system parameter.
The error may also occur if the arrangement
of text, data, and stack segments
requires too many segmentation registers, or
if there is not enough swap space during a
.IR fork .
.{n 13 \s-1EACCES\s+1 "Permission denied"
An attempt was made to access a file in a way forbidden
by the protection system.
.{n 14 \s-1EFAULT\s+1 "Bad address"
The system encountered a hardware fault in attempting to
use an argument of a system call.
.{n 15 \s-1ENOTBLK\s+1 "Block device required"
A nonblock file was mentioned where a block device was required,
e.g., in
.IR mount .
.{n 16 \s-1EBUSY\s+1 "Mount device busy"
An attempt to mount a device that was already mounted or
an attempt was made to dismount a device
on which there is an active file
(open file, current directory, mounted-on file, active text segment).
It will also occur if an attempt is made to enable accounting when it is
already enabled.
.{n 17 \s-1EEXIST\s+1 "File exists"
An existing file was mentioned in an inappropriate context,
e.g.,
.IR link .
.{n 18 \s-1EXDEV\s+1 "Cross-device link"
A link to a file on another device
was attempted.
.{n 19 \s-1ENODEV\s+1 "No such device"
An attempt was made to apply an inappropriate
system call to a device;
e.g., read a write-only device.
.{n 20 \s-1ENOTDIR\s+1 "Not a directory"
A nondirectory was specified where a directory
is required,
for example in a path prefix or
as an argument to
.IR chdir (S).
.{n 21 \s-1EISDIR\s+1 "Is a directory"
An attempt to write on a directory.
.{n 22 \s-1EINVAL\s+1 "Invalid argument"
Some invalid argument (e.g., dismounting a nonmounted device;
mentioning an undefined signal in
.IR signal ,
or
.IR kill ;
reading or writing a file for which
.I lseek\^
has generated a negative pointer).
Also set by the math functions described in the (S) entries
of this manual.
.{n 23 \s-1ENFILE\s+1 "File table overflow"
The system's table of open files is full,
and temporarily no more
.I opens\^
can be accepted.
.{n 24 \s-1EMFILE\s+1 "Too many open files"
No process may have more than 20 file descriptors open at a time.
.{n 25 \s-1ENOTTY\s+1 "Not a typewriter"
.{n 26 \s-1ETXTBSY\s+1 "Text file busy"
An attempt to execute a pure-procedure
program which is currently open for writing
(or reading).
Also an attempt to open for writing a pure-procedure
program that is being executed.
.{n 27 \s-1EFBIG\s+1 "File too large"
The size of a file exceeded the maximum
file size (1,082,201,088 bytes) or
.SM ULIMIT\*S;
see
.IR ulimit (S).
.{n 28 \s-1ENOSPC\s+1 "No space left on device"
During a
.I write\^
to an ordinary file,
there is no free space left on the device.
.{n 29 \s-1ESPIPE\s+1 "Illegal seek"
An
.I lseek\^
was issued to a pipe.
.{n 30 \s-1EROFS\s+1 "Read-only file system"
An attempt to modify a file or directory
was made
on a device mounted read-only.
.{n 31 \s-1EMLINK\s+1 "Too many links"
An attempt to make more than the maximum number of links (1000) to a file.
.{n 32 \s-1EPIPE\s+1 "Broken pipe"
A write on a pipe for which there is no process
to read the data.
This condition normally generates a signal;
the error is returned if the signal is ignored.
.{n 33 \s-1EDOM\s+1 "Math argument"
The argument of a function in the math package (S)
is out of the domain of the function.
.{n 34 \s-1ERANGE\s+1 "Result too large"
The value of a function in the math package (S)
is not representable within machine precision.
.{n 35 \s-1EUCLEAN\s+1 "Structure needs cleaning"
An attempt was made to
.IR mount (S)
a file system whose super-block is not flagged
.IR clean ().
.{n 36 \s-1EDEADLOCK\s+1 "Would deadlock"
A process' attempt to lock a file region 
would cause a deadlock
between processes vying for control of that region.
.{n 37 \s-1ENOTNAM\s+1 "Not a semaphore"
A 
.IR creatsem (),
.IR opensem (),
.IR waitsem (),
 or 
.IR sigsem ()
was issued
using an invalid semaphore identifier.
.{n 38 \s-1ENAVAIL\s+1 "Not available"
An 
.IR opensem (),
.IR waitsem ()
or 
.IR sigsem ()
was issued
to a semaphore that has not been initialized by a call to
.IR creatsem ().
A 
.IR sigsem ()
was issued to a semaphore out of sequence; i.e.,
before the process has issued the corresponding 
.IR waitsem ()
to the semaphore.
An 
.IR nbwaitsem ()
was issued to a semaphore guarding a resource
that is currently in use by another process.
The semaphore on which a process was waiting has been left in
an inconsistent state when the 
process controlling the semaphore
exits without relinquishing control properly; 
i.e., without issuing a 
.IR waitsem ()
on the semaphore.
.n{ 39 \s-1EISNAM\s0 "A name file"
A name file (semaphore, shared data, etc.) was specified
when not expected.
.SH "Definitions"
.SS "\fIProcess \s-1ID\s+1\fR"
Each active process in the system is uniquely identified by a
positive integer called a process
.SM ID\*S.
The range of this
.SM ID
is from 0 to 30,000.
.SS "\fIParent Process \s-1ID\s+1\fR"
A new process is created by a currently active
process; see
.IR fork (S).
The parent process
.SM ID
of a process is the process
.SM ID
of its creator.
.SS "\fIProcess Group \s-1ID\s+1\fR"
Each active process is a member of a process group that is
identified by a positive integer called the process group
.SM ID\*S.
This
.SM ID
is the process
.SM ID
of the group leader.
This grouping permits the signaling of related processes; see
.IR kill (S).
.SS "\fITty Group \s-1ID\s+1\fR"
Each active process can be a member of a terminal group that
is identified by a positive integer called the tty group
.SM ID\*S.
This grouping is used to terminate a group of related process upon termination
of one of the processes in the group; see
.IR exit (S)
and
.IR signal (S).
.SS "\fIReal User \s-1ID\s+1 and Real Group \s-1ID\s+1\fR"
Each user allowed on the system is 
identified by a positive integer called a real user
.SM ID\*S.
.PP
Each user is also a member of a group.
The group is identified by a positive integer called the real group
.SM ID\*S.
.PP
An active process has a real user
.SM ID
and real group
.SM ID
that are set to the real user
.SM ID
and real group
.SM ID\*S,
respectively, of the user responsible for the creation of the process.
.SS "\fIEffective User \s-1ID\s+1 and Effective Group \s-1ID\s+1\fR"
An active process has an effective user
.SM ID
and an effective group
.SM ID
that are used to determine file access permissions (see below).
The effective
user
.SM ID
and effective group
.SM ID
are equal to the process' real user
.SM ID
and real group
.SM ID
respectively, unless the process
or one of its ancestors evolved from a file that had the set-user-\s-1ID\s+1
bit or set-group
.SM ID
bit set; see
.IR exec (S).
.SS \fISuper-User\fR
A process is recognized as a
.I super-user\^
process and is granted special privileges if its effective user
.SM ID
is 0.
.SS "\fISpecial Processes\fR"
The processes with a process
.SM ID
of 0 and a process
.SM ID
of 1 are special processes and are referred to as
.IR proc0 " and " proc1.
.PP
.I Proc0\^
is the scheduler.
.I Proc1\^
is the initialization process 
.RI ( init ).
Proc1 is the ancestor of every other
process in the system and is used to control the process structure.
.SS "\fIFilename\fR"
Names consisting of up to 14 characters may be used to name an ordinary file,
special file or directory.
.PP
These characters may be selected from the set of all character values
excluding 0 (null) and the
.SM ASCII
code for a
.B /
(slash).
.PP
Note that it is generally unwise to use
.BR "*" ,
.BR "?" ,
.BR "[" ,
or
.B "]"
as part of filenames because of the special meaning attached to these
characters by the shell.
Likewise, the high order bit of the character should not be set.
.SS "\fIPathname and Path Prefix\fR"
A pathname is a null-terminated character string
starting with an optional slash
.RB ( / ),
followed by
zero or more directory names separated by slashes, optionally followed
by a filename.
A filename is a string of 1 to 14
characters other than the
.SM ASCII
slash and null, and
a directory name is a string of 1 to 14 characters
(other than the
.SM ASCII
slash and null)
naming a directory.
.PP
If a pathname begins with a slash, the path search begins at the
.I root\^
directory.
Otherwise, the search begins from the current working directory.
.PP
A slash by itself names the root directory.
.PP
Unless specifically stated otherwise,
the null pathname is treated as if it named
a nonexistent file.
.SS \fIDirectory\fR
.PP
Directory entries are called links.
By convention, a directory contains at least two links,
.B  .
and
.BR .. ,
referred to as
.I dot\^
and
.I dot-dot\^
respectively.
Dot refers to the directory itself and dot-dot refers to its parent
directory.
.SS "\fIRoot Directory and Current Working Directory\fR"
Each process has associated with it a concept of a root directory and
a current working directory for the purpose of resolving 
pathname searches.  A process' root directory need not be 
the root directory of the root
file system. 
See 
.IR chroot\^ (C)
and 
.IR chroot\^ (S).
.SS "\fIFile Access Permissions\fR"
.PP
Read, write, and execute/search permissions on a file are
granted to a process if one or more of the following are true:
.IP
The process' effective user
.SM ID
is super-user.
.IP
The process' effective user
.SM ID
matches the user
.SM ID
of the owner of the file
and the appropriate access bit of the
``owner'' portion (0700) of the file mode is set.
.IP
The process' effective user
.SM ID
does not match the user
.SM ID
of the owner of the file,
and the process' group
.SM ID
matches the group of the file and
the appropriate access bit of the ``group'' portion
(070) of the file mode is set.
.IP
The process' effective user
.SM ID
does not match the user
.SM ID
of the owner of the file,
and the process' effective group
.SM ID
does not match the group
.SM ID
of the file,
and the appropriate access bit of the ``other'' portion (07) of the
file mode is set.
.PP
Otherwise, the corresponding permissions are denied.
See \fIchmod\fR(C) and \fIchmod\fR(S).
.SH "See Also"
intro(C)
