.\" bm# 0000002335
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH CHMOD S 
.SH Name
chmod \- Changes mode of a file.
.SH Syntax
.B int chmod (path, mode)
.br
.B char \(**path;
.br
.B int mode;
.SH Description
.I Path\^
points to a
pathname
naming a file.
.I Chmod\^
sets the access permission portion of the named file's mode
according to the bit pattern contained in
.IR mode .
.PP
Access permission bits for 
.I mode
can be formed by adding any combination of the following:
.PP
.RS 
04000 Set user \s-1ID\s0 on execution
.br
02000 Set group \s-1ID\s0 on execution
.br
01000 Save text image after execution
.br
00400 Read by owner
.br
00200 Write by owner
.br
00100 Execute (or search if a directory) by owner
.br
00040 Read by group
.br
00020 Write by group
.br
00010 Execute (or search) by group
.br
00004 Read by others
.br
00002 Write by others
.br
00001 Execute (or search) by others
.RE
.PP
To change the mode of a file, the effective user
.SM ID
of the process must match the owner of the file or must
be super-user.
.PP
If the effective user
.SM ID
of the process is not
super-user,
mode bit 01000 (save text image on execution) is cleared.
.PP
If the effective user
.SM ID
of the process is not
super-user
or the effective group
.SM ID
of the process does not match the
group
.SM ID
of the file,
mode bit 02000 (set group
.SM ID
on execution)
is cleared.
.PP
If an executable file is prepared for sharing,
then mode bit 01000 prevents the system from
abandoning the swap-space image of the program-text portion
of the file when its last user
terminates.
Thus, when the next user executes the file,
the text need not be read from the file
system but can simply be swapped in, saving time.
Many systems have relatively small amounts of swap space, and the
same-text bit should be used sparingly, if at all.
.PP
.I Chmod\^
will fail and the file mode will be unchanged
if one or more of the following are true:
.IP
A component of
the
path prefix
is not a directory.
.SM
\%[ENOTDIR]
.IP
The named file does not exist.
.SM
\%[ENOENT]
.IP
Search permission is denied on a
component of the
path prefix.
.SM
\%[EACCES]
.IP
The effective user
.SM ID
does not match the owner of the file
and the effective user
.SM ID
is not super-user.
.SM
\%[EPERM]
.IP
The named file resides on a read-only file system.
.SM
\%[EROFS]
.IP
.I Path\^
points outside the process' allocated address space.
.SM
\%[EFAULT]
.SH "Return Value"
Upon successful completion, a value of 0
is returned.
Otherwise, a value of \-1 is returned and
.I errno\^
is set to indicate the error.
.SH "See Also"
chown(S), mknod(S)
