.\" bm# 0000002328
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH CREATSEM S
.SH Name
creatsem \- Creates an instance of a binary semaphore.
.SH Syntax
.B sem_num = creatsem(sem_name,mode);
.br
.B int sem_num,mode
.br
.B char *sem_name;
.SH Description
.I Creatsem
defines a binary semaphore named by
.I sem_name
to be used by
.IR waitsem (S)
and
.IR sigsem (S)
to manage mutually exclusive access to a resource, 
shared variable, or
critical section of a program.
.I Creatsem
returns a unique semaphore number
.I sem_num
which may then be used as the parameter in
.I waitsem
and
.I sigsem
calls.
Semaphores are special files of 0 length.
The filename space is used to provide
unique identifiers for semaphores.
.I Mode
sets the accessibility of the semaphore 
using the same format as file access bits.  
Access to a semaphore is granted only
on the basis of the read access bit;
the write and execute bits are ignored.
.PP
A semaphore can be operated on only by
a synchronizing primitive, such as
.I waitsem 
or 
.IR sigsem ,
by 
.I creatsem 
which initializes it to some value,
or by 
.I opensem 
which opens the semaphore for use by a process.
Synchronizing primitives
are guaranteed to be executed without interruption
once started.
These primitives are
used by associating a semaphore with each resource (including
critical code sections) to be protected.
.PP
The process controlling the semaphore should issue
.RS
.sp
sem_num = creatsem("semaphore", mode);
.sp
.RE
to create, initialize, and open the semaphore for that process.
All other processes using the semaphore should issue
.RS
.sp
sem_num = opensem("semaphore")
.sp
.RE
to access the semaphore's identification value.
Note that a process cannot open and use a semaphore that has not been
initialized by a call to \fIcreatsem\fR, 
nor should a process
open a semaphore more than once in one period of execution.
Both the creating and opening processes use
.I waitsem 
and 
.I sigsem 
to use the semaphore
.I sem_num.
.SH "See Also"
opensem(S), waitsem(S), sigsem(S).
.SH Diagnostics
.I Creatsem
returns the value \-1 if an error occurs.
If the semaphore named by sem_name is already open
for use by other processes, 
.I errno 
is set to \s-1EEXIST\s0. 
If the file specified exists 
but is not a semaphore type,
.I errno 
is set to \s-1ENOTNAM\s0.
If the semaphore has not been
initialized by a call to \fIcreatsem\fR, 
.I errno
is set to \s-1ENAVAIL\s0.
.SH Notes
After a 
.I creatsem
you must do a 
.I waitsem
to gain control of a given resource.
