.\" bm# 0000002323
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH CURSES S
.SH Name
curses \- Performs screen and cursor functions.
.SH Syntax
.B #include <curses.h>
.br
.B WINDOW *curscr, *stdscr;
.SH Description
These routines give the user a method
of updating screens with reasonable optimization.
They keep an image of the current screen,
.BR curscr ,
and the user modifies this image by modifying the standard screen,
.BR stdscr ,
or by setting up a new screen.  The
.I refresh 
and 
.I wrefresh
routines make the current screen look like the 
modified one.
In order to initialize the routines,
the routine
.I initscr 
must be called before any of the other routines
that deal with windows and screens
are used.
.P
The routines are linked with the loader options
.B \-lcurses
and 
.BR \-ltermcap .
.SH "See Also"
termcap(M), stty(C), setenv(S)
.br
.RI "\s-1XENIX\s0" "Library Guide"
.SH Functions
.nf
.PP
.B int addch(ch)
.B char ch;
		Adds a character to \fBstdscr\fP
.PP
.B int addstr(str)
.B char *str;
		Adds a string to \fBstdscr\fP
.PP
.B int box(win,vert,hor)
.B WINDOW *win;
.B char vert, hor;
		Draws a box around a window
.PP
.B int crmode()
		Sets cbreak mode
.PP
.B int clear()
		Clears \fBstdscr\fP
.PP
.B int clearok(win,state)
.B WINDOW *win;
.B bool state;
		Sets clear flag for \fIwin\fR
.PP
.B int clrtobot()
		Clears to bottom on \fBstdscr\fP
.PP
.B int clrtoeol()
		Clears to end of line on \fBstdscr\fP
.PP
.B int delch()
		Deletes character from \fBstdscr\fP
.PP
.B int deleteln()
		Deletes line from \fBstdscr\fP
.PP
.B int delwin(win)
.B WINDOW *win;
		Delete \fIwin\fP
.PP
.B int echo()
		Sets echo mode
.PP
.B int erase()
		Erase \fBstdscr\fP
.PP
.B int getch()
		Gets a char through \fBstdscr\fP
.PP
.B int getstr(str)
.B char *str;
		Gets a string through \fBstdscr\fP
.PP
.B int gettmode()
		Gets tty modes
.PP
.B int getyx(win,y,x)
.B WINDOW *win;
.B int x,y;
		Gets current (y,x) position of \fIwin\fP
.PP
.B int inch()
		Gets char at current (y,x) co-ordinates
.PP
.B WINDOW *initscr()
		Initializes screens
.PP
.B int insch(c)
.B char c;
		Inserts character in \fBstdscr\fP
.PP
.B int insertln()
		Inserts blank line in \fBstdscr\fP
.PP
.B int leaveok(win,state)
.B WINDOW *win;
.B bool state;
		Sets leave flag for \fIwin\fP
.PP
.B int longname(termbuf,name)
.B char *termbuf, *name;
		Gets long name from \fItermbuf\fR
.PP
.B int move(y,x)
.B int y,x;
		Moves to (y,x) on \fBstdscr\fP
.PP
.B int mvcur(lasty,lastx,newy,newx)	
.B int lasty, lastx, newy, newx;
		Moves cursor the from (lasty,lastx)
		to (newy,newx)
.PP
.B int mvwin(win,y,x)
.B WINDOW *win;
.B int y,x;
		Moves upper corner of \fIwin\fP to (y,x)
.PP
.B WINDOW *newwin(lines,cols,begin_y,begin_x)
.B int lines, cols, bigin_y, begin_x;
		Creates a new window
.PP
.B int nl()
		Sets newline mapping
.PP
.B int nocrmode()
		Unsets cbreak mode
.PP
.B int noecho()
		Unsets echo mode
.PP
.B int nonl()
		Unsets newline mapping
.PP
.B int noraw()
		Unsets raw mode
.PP
.B int overlay(win1,win2)
.B WINDOW *win1, *win2;
		Overlays \fIwin1\fP on \fIwin2\fP
.PP
.B int overwrite(win1,win2)
.B WINDOW *win1, *win2;
		Overwrites \fIwin1\fP on top of \fIwin2\fP
.PP
.B int printw(fmt,arg1,arg2,...)
.B char *fmt;
		Prints args on \fBstdscr\fP
.PP
.B int raw()
		Sets raw mode
.PP
.B int refresh()
		Makes current screen look like \fBstdscr\fP
.PP
.B int restty()
		Resets tty flags to stored value
.PP
.B int savetty()
		Stored current tty flags
.PP
.B int scanw(fmt,arg1,arg2,...)	
.B char *fmt;
		Scans for args through \fBstdscr\fP
.PP
.B int scroll(win)
.B WINDOW *win;
		Scrolls \fIwin\fP one line
.PP
.B int scrollok(win,state)
.B WINDOW *win;
.B bool state;
		Sets scroll flag
.PP
.B int setterm(name)
.B char *name;
		Sets term variables for name
.PP
.B int standend()
		Clears standout mode of \fBstdscr\fP
.PP
.B int standout()	
		Sets standout mode for characters in subsequent 
		output to \fBstdscr\fP
.PP
.B WINDOW *subwin(win,lines,cols,begin_y,begin_x)
.B WINDOW *win;
.B int lines, cols, begin_y, begin_x;
		Creates a subwindow in \fIwin\fP
.PP
.B int touchwin(win)
.B WINDOW *win;
		Prepares \fIwin\fP for complete update on
		next refresh. 
.PP
.B int unctrl(ch)
.B char ch;
		Printable version of \fIch\fR
.PP
.B int waddch(win,ch)
.B WINDOW *win;
.B char ch;
		Adds char to \fIwin\fP
.PP
.B int waddstr(win,str)
.B WINDOW *win;
.B char *str;
		Adds string to \fIwin\fP
.PP
.B int wclear(win)
.B WINDOW *win;
		Clear \fIwin\fP
.PP
.B int wclrtobot(win)
.B WINDOW *win;
		Clears to bottom of \fIwin\fP
.PP
.B int wclrtoeol(win)
.B WINDOW *win;
		Clears to end of line on \fIwin\fP
.PP
.B int wdelch(win)
.B WINDOW *win;
		Deletes current character from \fIwin\fP 
.PP
.B int wdeleteln(win)
.B WINDOW *win;
		Deletes line from \fIwin\fP
.PP
.B int werase(win)
.B WINDOW *win;
		Erase \fIwin\fP
.PP
.B int wgetch(win)
.B WINDOW *win;
		Gets a char through \fIwin\fP
.PP
.B int wgetstr(win,str)
.B WINDOW *win;
.B char *str;
		Gets a string through \fIwin\fP
.PP
.B int winch(win)
.B WINDOW *win;
		Gets char at current (y,x) in \fIwin\fP
.PP
.B int winsch(win,c)
.B WINDOW *win;
.B char c;
		Inserts character c in \fIwin\fP
.PP
.B int winsertln(win)
.B WINDOW *win;
		Inserts a blank line in \fIwin\fP
.PP
.B int wmove(win,y,x)
.B WINDOW *win;
.B int y,x;
		Sets current (y,x) co-ordinates on
.PP
.B int wprintw(win,fmt,arg1,arg2,...)
.B WINDOW *win;
.B char *fmt;
		Print args on \fIwin\fP
.PP
.B int wrefresh(win)
.B WINDOW *win;
		Makes screen look like \fIwin\fP
.PP
.B int wscanw(win,fmt,arg1,arg2,...)
.B WINDOW *win;
.B char *fmt;
		Scans for args through \fIwin\fP
.PP
.B int wstandend(win)
.B WINDOW *win;
		Clears standout mode for \fIwin\fP
.PP
.B int wstandout(win)
.B WINDOW *win;
		Sets standout mode for characters on
		subsequent output to \fIwin\fP
.fi
.SH Credit
This utility was developed 
at the University of California at Berkeley 
and is used with permission.
