.\" bm# 0000002317
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH EXEC S 
.SH Name
execl, execv, execle, execve, execlp, execvp \- Executes a file.
.SH Syntax
.B "int execl (path, arg0, arg1, ..., argn, 0)"
.br
.B char \(**path, \(**arg0, \(**arg1, ..., \(**argn;
.PP
.B int execv (path, argv)
.br
.B char \(**path, \(**argv[ ];
.PP
.B "int execle (path, arg0, arg1, ..., argn, 0, envp)"
.br
.B "char \(**path, \(**arg0, \(**arg1, ..., \(**argn, \(**envp[ ];"
.PP
.B int execve (path, argv, envp);
.br
.B char \(**path, \(**argv[ ], \(**envp[ ];
.PP
.B "int execlp (file, arg0, arg1, ..., argn, 0)"
.br
.B char \(**file, \(**arg0, \(**arg1, ..., \(**argn;
.PP
.B int execvp (file, argv)
.br
.B char \(**file, \(**argv[ ];
.SH Description
.I Exec\^
in all its forms transforms the calling process into a new process.
The new process is constructed from an ordinary, 
executable file called the ``new process file'' .
There can be no return from a successful 
.I exec\^
because the calling process is overlaid by the new process.
.PP
.I Path\^
points to a pathname that identifies the new process file.
.PP
.I File\^
points to the new process file.
The path prefix for this file is obtained by a search of the directories
passed as the
.I environment\^
line ``\s-1PATH\s+1 =''
(see
.IR environ (M)).
The environment
is supplied by the shell (see
.IR sh (C)).
.PP
.IR Arg0 ", " arg1 ", " ... ,
.I argn\^
are pointers to null-terminated character strings.
These strings constitute the argument list 
available to the new process.
By convention, at least
.I arg0\^
must be present, and it must point to a string that is the same as
.I path\^
(or its last component).
.PP
.I Argv\^
is an array of character pointers to null-terminated strings.
These strings constitute the argument list available to the new process.
By convention,
.I argv\^
must have at least one member, and it must point to a string that is the same as
.IR path\^
(or its last component).
.I Argv\^
is terminated by a null pointer.
.PP
.I Envp\^
is an array of character pointers to null-terminated strings.
These strings constitute the environment
for the new process.
.I Envp\^
is terminated by a null pointer.
.PP
File descriptors open in the calling process 
remain open in the new process,
except for those whose
\%close-on-exec 
flag is set; see 
.IR fcntl (S).
For those file descriptors that remain open, 
the file pointer is unchanged.
.PP
Signals set to terminate the calling process 
will be set to terminate the
new process.
Signals set to be ignored by the calling process will be set to be
ignored by the new process.
Signals set to be caught by the calling process will be set 
to terminate new process; see 
.IR signal (S).
.PP
If the set-user-\s-1ID\s+1
mode bit of the new process file is set
(see 
.IR chmod (S)),
.I exec\^
sets the effective user
.SM ID
of the new process to the owner
.SM ID
of the new process file.
Similarly, if the set-group-\s-1ID\s+1 mode bit of the
new process file is set, the effective group
.SM ID
of the new process
is set to the group
.SM ID
of the new process file.
The real user
.SM ID
and real group 
.SM ID
of the new process remain the same as those of the calling process.
.PP
Profiling is disabled for the new process; see
.IR profil (S).
.PP 
The new process also inherits the following attributes from the calling process:
.PP
.PD 
.RS 
.PP
Nice value (see 
.IR nice (S))
.PP
Process
.SM ID
.PP
Parent process
.SM ID
.PP
Process group
.SM ID
.PP
tty group
.SM ID
(see 
.IR exit (S)
and
.IR signal (S))
.PP
Trace flag (see
.IR ptrace "(S) request 0)"
.PP
Time left until an alarm clock signal (see 
.IR alarm (S))
.PP
Current working directory
.PP
Root directory
.PP
File mode creation mask (see
.IR umask (S))
.PP
File size limit (see 
.IR ulimit (S))
.PP
.IR utime ,
.IR stime ,
.IR cutime ,
and
.I cstime\^
(see 
.IR times (S))
.RE
.PP
From C, two interfaces are available.
.I Execl
is useful when a known file with known arguments is
being called;
the arguments to
.I execl
are the character strings
constituting the file and the arguments.
The first argument is conventionally
the same as the filename (or its last component).
A 0 argument must end the argument list.
.PP
The
.I execv
version is useful when the number of arguments is unknown
in advance.
The arguments to
.I execv
are the name of the file to be
executed and a vector of strings containing the arguments.
The last argument string must be followed by a 0 pointer.
.PP
When a C program is executed, it is called as follows:
.PP
	main(argc, argv, envp)
.br
	int argc;
.br
	char **argv, **envp;
.PP
where
.IR argc ""
is the argument count
and
.IR argv ""
is an array of character pointers to the arguments themselves.
As indicated,
.IR argc ""
is conventionally at least one
and the first member of the array points to a
string containing the name of the file.
.PP
.I Argv
is directly usable in another
.I execv
because
.IR argv [ argc ]
is 0.
.PP
.I Envp
is a pointer to an array of strings that constitute
the
.I environment
of the process.
Each string consists of a name, an ``='', and a null-terminated value.
The array of pointers is terminated by a null pointer.
The shell
.IR sh (C)
passes an environment entry for each global shell variable
defined when the program is called.
See
.IR environ (M)
for some conventionally used names.
The C run-time start-off routine places a copy of
.I envp
in the global cell
.I environ,
which is used by
.IR execv \ and \ execl
to pass the environment to any subprograms executed by the
current program.
The
.I exec
routines use lower-level routines as follows
to pass an environment explicitly:
.PP
.RS
.nf
execle(file, arg0, arg1, . . . , argn, 0, environ);
execve(file, argv, environ);
.fi
.RE
.PP
.I Execlp
and
.I execvp
are called with the same arguments as
.I execl
and
.I execv,
but duplicate the shell's actions in searching for an executable
file in a list of directories.
The directory list is obtained from the environment.
.PD
.PP
.I Exec\^
will fail and return to the calling process if one or more of the
following are true:
.IP
One or more components of the new process file's pathname do not exist.
.SM
\%[ENOENT]
.IP
A component of the new process file's path prefix is not a directory.
.SM
\%[ENOTDIR]
.IP
Search permission is denied for a directory listed in the new process file's
path prefix.
.SM
\%[EACCES]
.IP
The new process file is not an ordinary file.
.SM
\%[EACCES]
.IP
The new process file mode denies execution permission.
.SM
\%[EACCES]
.IP
The new process file has the appropriate access permission, but has an
invalid magic number in its header.
.SM
\%[ENOEXEC]
.IP
The new process file is a pure procedure (shared text) file that is
currently open for writing by some process.
.SM
\%[ETXTBSY]
.IP
The new process requires more memory than is allowed by the system-imposed
maximum.
.SM
\%[ENOMEM]
.IP
The number of bytes in the new process' argument list is greater than the
system-imposed limit of 5120 bytes.
.SM
\%[E2BIG]
.IP
The new process file is not as long as indicated by the size values in its
header.
.SM
\%[EFAULT]
.IP
.IR Path ,
.IR argv ,
or
.I envp\^
point to an illegal address.
.SM
\%[EFAULT]
.SH "Return Value"
If 
.I exec\^
returns to the calling process an error has occurred; the return value
will be \-1 and 
.I errno\^
will be set to indicate the error.
.SH "See Also"
exit(S), fork(S)
