.\" bm# 0000002313
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH FCNTL S
.SH Name
fcntl \- Controls open files.
.SH Syntax
.B #include <fcntl.h>
.PP
.B int fcntl (fildes, cmd, arg)
.br
.B int fildes, cmd, arg;
.SH Description
.I Fcntl\^
provides for control over open files.
.I Fildes\^
is an open
file descriptor
obtained from a
.IR creat ,
.IR open ,
.IR dup ,
.IR fcntl ,
or
.I pipe\^
system call.
.PP
The
.IR cmd s
available are:
.TP .75i
.SM F_DUPFD
Returns a new
file descriptor
as follows:
.IP
Lowest numbered available
file descriptor
greater than or equal to
.IR arg .
.IP
Same open file (or pipe) as the original file.
.IP
Same file pointer as the original file
(i.e., both file descriptors share one
file pointer).
.IP
Same access mode (read, write or read/write).
.IP
Same file status flags (i.e., both file descriptors share the same
file status flags).
.IP
The close-on-exec flag associated with the new file descriptor is set to
remain open across
.IR exec (S)
system calls.
.TP
.SM F_GETFD
Gets the close-on-exec flag associated with the file descriptor
.IR fildes .
If the low-order bit is
.B 0
the file will remain open across
.IR exec ,
otherwise
the file will be closed upon execution of
.IR exec .
.TP
.SM F_SETFD
Sets the close-on-exec flag associated with
.I fildes\^
to the low-order bit of
.I arg\^
.RB ( 0
or
.B 1
as above).
.TP
.SM F_GETFL
Gets
.I file\^
status flags.
.TP
.SM F_SETFL
Sets
.I file\^
status flags to
.IR arg .
Only certain flags can be set.
.PP
.I Fcntl\^
fails if one or more of the following
is true:
.IP
.I Fildes\^
is not a valid open
file descriptor.
.SM
\%[EBADF]
.IP
.I Cmd\^
is
.SM F_DUPFD
and 20 file descriptors are currently open.
.SM
\%[EMFILE]
.IP
.I Cmd\^
is
.SM F_DUPFD
and
.I arg\^
is negative or greater than 20.
.SM
\%[EINVAL]
.SH "Return Value"
Upon successful completion,
the value returned depends on
.I cmd\^
as follows:
.RS
.TP .75i
.SM F_DUPFD
A new file descriptor
.TP
.SM F_GETFD
Value of flag (only the low-order
bit is defined)
.TP
.SM F_SETFD
Value other than \-1
.TP
.SM F_GETFL
Value of file flags
.TP
.SM F_SETFL
Value other than \-1
.RE
.PP
.PD
Otherwise, a value of \-1 is returned and
.I errno\^
is set to indicate the error.
.SH "See Also"
close(S), exec(S), open(S)
