.\" bm# 0000002416
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH LOCKING S
.SH Name
locking \- Locks or unlocks a file region for reading or writing.
.SH Syntax
.B locking(fildes, mode, size);
.br
.B int fildes, mode;
.br
.B long size;
.SH Description
.I Locking
allows a specified number of bytes in a file 
to be controlled by the locking process.
Other processes which attempt to read or write a portion of the file
containing the locked region may
sleep until the area becomes unlocked 
depending upon the mode in which the file region was locked.
A process that attempts to write to or read a file region that has been
locked against reading and writing 
by another process (using the 
.SM LK_LOCK 
or
.SM
LK_NBLCK 
mode) will sleep until the region 
of the file has been released
by the locking process.
A process that attempts to write to a file region that has been
locked against writing by another process (using the 
.SM LK_RLCK 
or
.SM LK_NBRLCK 
mode) will sleep until the region of the file has 
been released by the locking process, 
but a read request for that file region will proceed normally.
.sp
A process that attempts to lock a region of a file 
that contains areas that
have been locked by other processes will sleep if it has specified the
.SM LK_LOCK or 
.SM LK_RLCK mode in its lock request, 
but will return with the error
.SM EACCES 
if it specified 
.SM LK_NBLCK or 
.SM LK_NBRLCK.
.sp
.I Fildes
is the value returned from a successful
.I creat, open, dup,
or
.I pipe
system call.
.sp
.I Mode
specifies the type of lock operation to be performed on the file region.
The available values for mode are:
.sp
.TP
\s-1LK_UNLCK\s+1 0 
Unlocks the specified region.
The calling process releases a
region of the file it had previously locked.
.TP
\s-1LK_LOCK\s+1 1 
Locks the specified region.
The calling process will sleep until the
entire region is available if any part of
it has been locked by a different process.
The region is then locked for the calling
process and no other process may read or
write in any part of the locked region.
(lock against read and write).
.bp
.TP
\s-1LK_NBLCK\s+1 2 
Locks the specified region.
If any part of the region is already locked
by a different process, return the error
.SM EACCES
instead of waiting for the region
to become available for locking (nonblocking
lockrequest).
.sp 1
.TP
\s-1LK_RLCK\s+1 3 
Same as 
.SM LK_LOCK 
except that the locked region
may be read by other processes (read permitted lock).
.TP
\s-1LK_NBRLCK\s+1 4 
Same as 
.SM LK_NBLCK 
except that the locked region may be read 
by other processes (nonblocking, read permitted lock).
.RE
.sp 1
.I Size
is the number of contiguous bytes to be locked or unlocked.
The region to be locked starts at the current offset in the file.
If
.I size
is 0, the entire file (up to a maximum of 2 to the
power of 30 bytes) 
is locked or unlocked.
.I Size
may extend beyond the end of the file, in which case only the
process issuing the lock call may access or add information to the file
within the boundary defined by size.
.PP
The potential for a deadlock occurs 
when a process controlling a locked area
is put to sleep by accessing another process' locked area.
Thus calls to
.I locking, read,
or
.I write
scan for a deadlock prior to sleeping on a locked region.
An error return
is made if sleeping on the locked region would cause a deadlock.
.PP
Lock requests may, in whole or part, 
contain or be contained by a previously
locked region for the same process.
When this occurs, or when adjacent
regions are locked, the regions are combined into a single area if the
mode of the lock is the same 
(i.e.; either read permitted or regular lock).
If the mode of the overlapping locks differ, 
the locked areas will be assigned assuming that the
.I most recent request
must be satisfied.
Thus if a read only lock is applied to a region, 
or part of a region, that
had been previously locked 
by the same process against both reading and
writing, the area of the
file specified by the new lock 
will be locked for read only, while the
remaining region, if any, 
will remain locked against reading and writing.
There is no arbitrary limit to the number of regions 
which may be locked in a file.
There is however a system-wide limit 
on the total number of locked regions.
This limit is 200 for 
.SM XENIX 
systems.
.PP
Unlock requests may, in whole or part, 
release one or more locked regions
controlled by the process.
When regions are not fully released, the
remaining areas are still locked by the process.
Release of the center
section of a locked area requires 
an additional locked element to hold
the separated section.
If the lock table is full, an error is returned,
and the requested region is not released.
Only the process which locked the file region may unlock it.
An unlock request for a region 
that the process does not have locked, or that
is already unlocked, has no effect.
When a process terminates, 
all locked regions controlled by that process are unlocked.
.PP
If a process has done more than one open on a file,
.I all 
locks put on the file by that process will be
released on the first close of the file.
.PP
Although no error is returned if locks are applied 
to special files or pipes,
read/write operations on these types of files will ignore the locks.
Locks may not be applied to a directory.
.PP
.SH "See Also"
creat(S), open(S), read(S), write(S), dup(S), close(S), lseek(S)
.SH Diagnostics
.I Locking
returns the value (int) -1 if an error occurs.
If any portion of the region
has been locked by another process for the 
.SM LK_LOCK 
and 
.SM LK_RLCK 
actions
and the lock request is to test only,
.I errno 
is set to \s-1EACCES\s+1.
If the file specified is a directory,
.I errno 
is set to \s-1EACCES\s+1.
If locking the region would
cause a deadlock,
.I errno 
is set to \s-1EDEADLOCK\s+1.
If there are no more free internal locks,
.I errno 
is set to \s-1EDEADLOCK\s+1.
