.\" bm# 0000002411
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH MKNOD S 
.SH Name
mknod \- Makes a directory, or a special or ordinary file.
.SH Syntax
.B int mknod (path, mode, dev)
.br
.B char \(**path;
.br
.B int mode, dev;
.SH Description
.I Mknod\^
creates a new file named by the pathname pointed to by
.IR path .
The mode of the new file is initialized from
.IR mode .
Where the value of
.I mode\^
is interpreted as follows:
.sp
.RS
0170000 File type; one of the following:
.br
	0010000 Named pipe special
.br
	0020000 Character special
.br
	0040000 Directory
.br
	0050000 Name special file
.br
	0060000 Block special
.br
	0100000 or 0000000 Ordinary file
.sp
0004000 Set user
.SM ID
on execution
.sp
0002000 Set group
.SM ID
on execution
.sp
0001000 Save text image after execution
.sp
0000777 Access permissions; constructed from the following
.br
	0000400 Read by owner
.br
	0000200 Write by owner
.br
	0000100 Execute (search on directory) by owner
.br
	0000070 Read, write, execute (search) by group
.br
	0000007 Read, write, execute (search) by others
.RE
.PP
Values of
.I mode
other than those above are undefined
and should not be used.
.PP
The file's owner
.SM ID
is set to the process' effective user
.SM ID\*S.
The file's group
.SM ID
is set to the process' effective group
.SM ID\*S.
.PP
The low-order 9 bits of
.I mode
are modified by
the process' file mode creation mask:
all bits set in the process' file mode creation mask are cleared.
See
.IR umask (S).
If
.I mode\^
indicates a block, character, or name special file, then
.I dev\^
is a configuration dependent
specification of a character or block I/O device.
If
.I mode\^
does not indicate a block, character, or name special file, then
.I dev\^
is ignored.
For block and character special files, 
.I dev\^
is the special file's device number.
For name special files,
.I dev\^
is the type of the name file,
either 
a shared memory file or a semaphore.
.PP
.I Mknod\^
may be invoked only by the super-user 
for file types other than named pipe special.
.PP
.I Mknod\^
will fail and the new file will not be created
if one or more of the following are true:
.IP
The process' effective user
.SM ID
is not super-user.
.SM
\%[EPERM]
.IP
A component of the
path prefix
is not a directory.
.SM
\%[ENOTDIR]
.IP
A component of the
path prefix
does not exist.
.SM
\%[ENOENT]
.IP
The directory in which the file is to be created
is located on a read-only file system.
.SM
\%[EROFS]
.IP
The named file exists.
.SM
\%[EEXIST]
.IP
.I Path\^
points outside the process' allocated address space.
.SM
\%[EFAULT]
.SH "Return Value"
Upon successful completion a value of 0 is returned.
Otherwise, a value of \-1 is returned and
.I errno\^
is set to indicate the error.
.SH "See Also"
mkdir(C), mknod(C), chmod(S), creatsem(S), exec(S),
sdget(S), umask(S), filesystem(F)
.SH Notes
Semaphore files should be created with the 
.IR creatsem (S)
system call.
.P
Share data files should be created with the 
.IR sdget (S)
system call.
