.\" bm# 0000002396
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH PTRACE S 
.SH Name
ptrace \- Traces a process.
.SH Syntax
.B #include <sys/types.h>
.PP
.B int ptrace (request, pid, addr, data);
.br
.B int request, pid, data;
.SH Description
.I Ptrace\^
provides a means by which a parent process
may control the execution of a child process.
Its primary use is in the implementation of breakpoint debugging; see
.IR adb\^ (CP).
The child process behaves normally until it encounters a signal (see
.IR signal\^ (S)
for the list), at which time it enters a stopped state
and its parent is notified via
.IR wait\^ (S).
When the child is in the stopped state,
its parent can examine and modify its ``memory image'' using
.IR ptrace .
Also, the parent can cause the child either to terminate
or continue, with the possibility 
of ignoring the signal that caused it to stop.
.PP
The
.I addr\^
argument is dependant on the underlying machine type, specifically
the process memory model. On systems where the memory management
mechanism provides a uniform and linear address space to user
processes, the argument is declared as:
.PP
.RS
int *addr;
.RE
.PP
which is sufficient to address any location in the process' memory.
On machines where the user address space is segmented (even if the
particular program being traced has only one segment allocated),
the form of the
.I addr\^
argument is:
.PP
.RS
.nf
struct saddr {
	unsigned short  sa_seg;
	long		segment;
}  *addr;
.fi
.RE
.PP
which allows the caller to specify segment and offset in the process
address space.
.PP
The
.I request\^
argument determines the precise action to be taken by
.I ptrace\^
and is one of the following:
.RS 0.5i
.TP 5
0
This request
must be issued by the child process if it is to be traced by its parent.
It turns on the child's trace flag that stipulates that the child should be
left in a stopped state upon receipt of
a signal rather than the state specified by
.IR func ;
see
.IR signal (S).
The
.IR pid ", " addr ", and " data
arguments are ignored, and a return value is not defined for this request.
Peculiar results will ensue if the parent does not expect to trace the child.
.RE
.PP
The remainder of the requests can only be used by the parent process.
For each,
.I pid\^
is the process
.SM ID
of the child.
The child must be in a stopped state before these requests are made.
.RS .5i
.TP 5
1, 2
The word at location
.I addr\^
in the address space of the child is returned to the parent process.
If I and D
space are separated,
request
.B 1
returns a word from I space, and
request
.B 2
returns a word from D space.
If I and D
space are not separated,
either request
.B 1
or request
.B 2
may be used with equal results.
If executed in an 80286 environment and 
.I sa_seg
contains the selector for the Local Descriptor
Table (\s-1LDT\s0), the word at location 
.I sa_off
in the \s-1LDT\s0 is returned.
The
.I data\^
argument is ignored.
These two requests will fail if
.I addr\^
is not the start address of a word, in which case a value of \-1 is
returned to the parent process and the parent's
.I errno\^
is set to
.SM \%EIO.
.TP 5
3
With this request, the word at location
.I addr\^
in the child's
.SM USER
area in the system's address space (see
.B <sys/user.h>)
is returned to the parent process.
When executed in a segmented environment,
.I sa_seg
is ignored.
The
.I data\^
argument is ignored.
This request will fail if
.I addr\^
is not the start address of a word or is outside the
.SM USER
area, in which case a value of \-1 is returned to the parent process and
the parent's
.I errno\^
is set to
.SM EIO.
.TP 5
4, 5
With these requests, the value given by the
.I data\^
argument is written into the address space of the child at location
.IR addr .
If I and D
space are separated,
request 4 writes a word into I space, and
request 5 writes a word into D space.
If I and D
space are not separated,
either request 4 or request 5 may be used with equal results.
Upon successful completion, 
the value written into the address space of the
child is returned to the parent.
These two requests will fail if
.I addr\^
is a location in a pure procedure space
and another process is executing in that space,
or
.I addr\^
is not the start address of a word.
Upon failure a value of \-1 is returned to the parent
process and the parent's
.I errno\^
is set to
.SM EIO\*S.
.TP 5
6
With this request, a few entries in the child's
.SM USER
area can be written.
.I Data\^
gives the value that is to be written and
.I addr\^
is the location of the entry.
The few entries that can be written follow:
.br
.ne 1i
.RS 0.5i
.IP
\-The general registers
.IP
\-Any floating-point status registers
.RE
.TP 5
7
This request causes the child to resume execution.
If the
.I data\^
argument is 0, 
all pending signals including the one that caused the child to
stop are canceled before it resumes execution.
If the
.I data\^
argument is a valid signal number, 
the child resumes execution as if it had
incurred that signal and any other pending signals are canceled.
In a linear address space memory model, the value of
.I addr\^
must be (int *)1, or in a segmented address space the 
.I sa_seg
of
.I addr\^
must be zero and the 
.I sa_off
must be (int *)1.
Upon successful completion, the  value of
.I data\^
is returned to the parent.
This request will fail if
.I data\^
is not 0 or a valid signal number, 
in which case a value of \-1 is returned
to the parent process and the parent's
.I errno\^
is set to
.SM EIO\*S.
.TP 5
8
This request causes the child to terminate 
with the same consequences as
.IR exit (S).
.TP 5
9
Execution continues as in request 7; however, as soon as possible
after execution of at least one instruction, execution stops again.
The signal number from the stop is 
.SM SIGTRAP. 
This is part of the
mechanism for implementing breakpoints. The exact implementation
and behaviour is somewhat CPU dependent.
.PP
As indicated, these calls (except for request 0) can be used
only when the subject process has stopped. The
.I wait\^
system call is used to determine when a process stops; in such a
case the termination status returned by
.I wait\^
has the value 0177 to indicate stoppage rather than genuine termination.
.PP
To prevent security violations,
.I ptrace\^
inhibits the set-user-id facility
on subsequent
.IR  exec (S)
calls.
If a traced process calls
.IR exec ,
it will stop before executing the first instruction of the new image
showing signal
.SM
SIGTRAP.
.SH Errors
.I Ptrace\^
will in general fail if one or more of the following are true:
.IP
.I Request\^
is an illegal number.
.SM
\%[EIO]
.IP
.I Pid\^
identifies a child that does not exist or has not executed a
.I ptrace\^
with request
0.
.SM
\%[ESRCH]
.PP
A return value of \-1 does not always indicate an
error.  To resolve this ambiguity, the
.I errno
variable is cleared on each call to 
.IR ptrace . 
If the return value is \-1, there is no error unless
.I errno 
is nonzero. 
.SH "Notes"
The implementation and precise behavior of this system call is
inherently tied to the specific CPU and process memory model in
use on a particular machine. Code using this call is likely to
not be portable across all implementations without some change.
.PP
System calls cannot be single-stepped. If a 
.I ptrace
call requests a single step through a system call,
the trace bit is cleared, and the user program will
run to completion or until it encounters an
explicitly set breakpoint.
.SH "See Also"
adb(CP), exec(S), signal(S), wait(S), machine(M)
