.\" bm# 0000002388
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH REGEX S
.SH Name
regex, regcmp \- Compiles and executes regular expressions.
.SH Syntax
.B char \(**regcmp(string1[,string2, .\|.\|.],0);
.br
.B char \(**string1, \(**string2, .\|.\|.;
.PP
.B char \(**regex(re,subject[,ret0, .\|.\|.]);
.br
.B char \(**re, \(**subject, \(**ret0, .\|.\|.;
.SH Description
.I Regcmp\^
compiles a regular expression 
and returns a pointer to the compiled form.
.IR Malloc\^ (S)
is used to create space for the compiled expression.
It is the user's responsibility to free unneeded space so allocated.
A zero return from
.I regcmp\^
indicates an incorrect argument.
.IR Regcmp\^ (CP)
has been written to generally preclude the need
for this routine at execution time.
.P
.I Regex\^
executes a compiled pattern against the subject string.
Additional arguments are passed to receive values back.
.I Regex\^
returns zero on failure 
or a pointer to the next unmatched character on success.
A global character pointer
.BI _ loc1\^
points to where the match began.
Although
.I regcmp\^
and
.I regex\^
were derived from the editor,
\fIed\^\fP(C),
the syntax and semantics have been changed slightly.
The following are the valid symbols and their associated meanings.
.TP "\w'\fB(.\|.\|.\^)$n\fR\ \ \ 'u"
.B [\|]\|*\|.^
These symbols retain their current meaning.
.TP
.B $
Matches the end of the string, \en matches the newline.
.TP
.B \-
Within brackets the minus means
.IR through .
For example,
.B [\^a\-z\^]
is equivalent to
.BR [\^abcd\|.\|.\|.xyz\^] .
The \fB\-\fP can
appear as itself only if used as the last or
first character.
For example, the character class expression
.B [\^]\-\^]
matches the characters
.BR ] \ and\  \- .
.TP
.B +
A regular expression followed by \fB+\fP means
"one or more times".
For example,
.B [0\-9]+
is equivalent to
.BR [0\-9][0\-9]\(** .
.TP
.B "{m} {m,} {m,u}"
Integer values enclosed in \fB{\|}\fP indicate the
number of times the preceding regular expression is to be applied.
.I m\^
is the minimum number and
.I u\^
is a number, less than 256, which is the maximum.
If only
.I m\^
is present (e.g., {m}),
it indicates the exact number of times the regular
expression is 
.br
.ne 1i
to be applied.
{m,} is analogous to {m,infinity}.
The plus (\fB+\fP) and star (\fB\(**\fP) operations are
equivalent to {1,} and {0,} respectively.
.TP
.B "( .\|.\|. )$\fIn\^\fP"
The value of the enclosed regular expression is
to be returned.
The value
will be stored in the
(\fIn+1\fR)th
argument following the subject argument.
At present,
at most ten enclosed regular expressions are allowed.
.I Regex\^
makes its assignments unconditionally.
.TP
.B "( .\|.\|. )"
Parentheses are used for grouping.
An operator, e.g.
.BR \(** ", " + ", " {\|} ,
can work on a single character or a regular
expression enclosed in parenthesis.
For example, (a\(**(cb+)\(**)$0.
.PP
By necessity, all the above defined symbols are special.
They must, therefore, be escaped to be used as themselves.
.SH Examples
\fIExample 1\fR:
.sp
.RS
.nf
char \(**cursor, \(**newcursor, \(**ptr;
	\&.\|.\|.
newcursor = regex((ptr=regcmp("^\\n",0)),cursor);
free(ptr);
.fi
.RE
.PP
This example will match a leading newline in the subject string
pointed at by cursor.
.PP
\fIExample 2\fR:
.sp
.RS
.nf
char ret0[9];
char \(**newcursor, \(**name;
	\&.\|.\|.
name = regcmp("([A\-Za\-z][A\-za\-z0\-9\_]{0,7})$0",0);
newcursor = regex(name,"123Testing321",ret0);
.fi
.RE
.PP
This example will match through the string ``Testing3'' and will return
the address of the character after the last matched character (cursor+11).
The string ``Testing3'' will be copied to the
character array
.IR ret0 .
.PP
\fIExample 3\fR:
.RS
.nf
#include "file.i"
char \(**string, \(**newcursor;
	\&.\|.\|.
newcursor = regex(name,string);
.fi
.RE
.PP
This example applies a precompiled regular expression
in
.B file.i
(see
.IR regcmp (CP))
against
.IR string .
.br
.ne 1i
.SH "See Also"
ed(C),
regcmp(CP),
malloc(S)
.SH Notes
The user program may run out of memory if
.I regcmp\^
is called iteratively without freeing the vectors no longer required.
The following user-supplied replacement for 
.IR malloc\^ (S)
reuses the same vector saving time and space:
.PP
.RS
.nf
/\(** \|user's \|program \|\(**/
	\&.\|.\|.
malloc(n)
{
	static int rebuf[256];
	return &rebuf;
}
.fi
.RE
