.\" bm# 0000002387
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH SBRK S
.SH Name
sbrk, brk \- Changes data segment space allocation.
.SH Syntax
.B  char *sbrk (incr)
.br
.B int incr;
.PP
.B char *brk (addr)
.br
.B char *addr;
.SH Description
.I Sbrk\^
and
.I brk\^
are used to dynamically change the amount of space allocated
for the calling process' data segment; see
.IR exec (S).
The change is made by resetting the process' break value.
The break value
is the address of the first location beyond the end of the data segment.
The amount of allocated space increases as the break value increases.
.PP
.I Sbrk\^
adds 
.I incr\^
bytes to the break value and changes the allocated space accordingly.
.I Incr\^
can be negative, 
in which case the amount of allocated space is decreased.
.PP
In large model programs, if 
.I incr
is greater than the number of unallocated bytes remaining in the
current data segment, 
.I sbrk\^
automatically allocates all the requested bytes in
a new data segment.  This guarantees that the 
requested bytes will reside entirely in one 
segment.  If 
.I incr
is negative and equal to the number of allocated
bytes in the current data segment, the 
segment is automatically freed for other use.  If 
.I incr
is greater than the number of allocated bytes, the
segment is freed, and the additional bytes are 
removed from the next data segment containing space
allocated by
.IR sbrk .
.PP
.I Sbrk\^
will fail without making any change in the allocated space
if such a change would result in more space being allocated
than is allowed by a system-imposed maximum (see
.IR ulimit (S)).
.SM
\%[ENOMEM]
.PP
.I Brk\^
sets the the current break value to 
.IR addr ,
and changes the allocated space accordingly.  
.I Brk\^
fails if the address references a data segment that
does not exist, or if it references beyond the
maximum possible size of the current data segment.
.SH "Return Value"
Upon successful completion,
.I sbrk\^
and
.I brk\^
return pointers to the beginning of the allocated
space.  Otherwise, a value of \-1 is returned and
.I errno\^
is set to indicate the error.
In large model programs, if 
.I sbrk\^
allocates a new data segment, the return value is
the starting address of that new segment.
.SH "See Also"
exec(S)
.SH Notes
In large model programs, the call ``sbrk(0)'' does not 
necessarily return the starting address of the next
.I sbrk\^
call.  In particular, if the next call causes an
additional data segment to be allocated, the
break values returned by these two calls will not be
the same.  The return value from ``sbrk(0)'' should only
be regarded as a marker for the original end of
data.
