.\" bm# 0000002386
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH SCANF S
.SH Name
scanf, fscanf, sscanf \- Converts and formats input.
.SH Syntax
.B #include <stdio.h>
.PP
.B int scanf (format
[
.B ,
pointer ] .\|.\|.
.B )
.br
.B char \(**format;
.PP
.B int fscanf (stream, format
[
.B ,
pointer ] .\|.\|.
.B )
.br
.SM
.B FILE
.B \(**stream;
.br
.B char \(**format;
.PP
.B int sscanf (s, format
[
.B ,
pointer ] .\|.\|.
.B )
.br
.B char \(**s, \(**format;
.SH Description
.I Scanf\^
reads from the standard input stream
.IR stdin .
.I Fscanf\^
reads from the named input
.IR stream .
.I Sscanf\^
reads from the character string
.IR s .
Each function reads characters, interprets
them according to a format, and stores the results in its arguments.
Each expects, as arguments,
a control string
.I format\^
described below,
and a set of
.I pointer\^
arguments
indicating where the converted input should be stored.
.PP
The
control string
usually contains
conversion specifications, which are used to direct interpretation
of input sequences.
The control string may contain:
.PP
.TP 3
1.
Blanks, tabs, or newlines,
which cause input to be read up to the next
nonwhitespace character.
.TP
2.
An ordinary character (not
.BR % ),
which must match
the next character of the input stream.
.TP
3.
Conversion specifications, consisting of the
character
.BR % ,
an optional assignment suppressing character
.BR \(** ,
an optional numerical maximum field width, and a conversion
character.
.PD
.PP
A conversion specification directs the conversion of the
next input field; the result
is placed in the variable pointed to by the corresponding argument,
unless assignment suppression was
indicated by
.BR \(** .
An input field is defined as a string of nonspace characters;
it extends to the next inappropriate character or until the field
width, if specified, is exhausted.
.PP
The conversion character indicates the interpretation of the
input field; the corresponding pointer argument must
usually be of a restricted type.
The following conversion characters are allowed:
.PP
.TP
.B %
A single
.B %
is expected
in the input at this point;
no assignment is done.
.TP
.B d
A decimal integer is expected;
the corresponding argument should be an integer pointer.
.TP
.B o
An octal integer is expected;
the corresponding argument should be an integer pointer.
.TP
.B x
A hexadecimal integer is expected;
the corresponding argument should be an integer pointer.
.TP
.B s
A character string is expected;
the corresponding argument should be a character pointer
pointing to an array of characters large enough to accept the
string and a terminating
.BR \e0 ,
which will be added automatically.
The input field is terminated by a space character
or a newline.
.TP
.B c
A character is expected; the
corresponding argument should be a character pointer.
The normal skip over space characters is suppressed
in this case;
to read the next nonspace character, use
.BR %1s .
If a field width is given, the corresponding argument
should refer to a character array; the
indicated number of characters is read.
.TP
\f3e\fP,\f3f\fP
A floating-point number is expected;
the next field is converted accordingly and stored through the
corresponding argument, which should be a pointer to a
.IR float .
The input format for
floating-point numbers is
an optionally signed
string of digits,
possibly containing a decimal point, followed by an optional
exponent field consisting of an
.B E
or an
.BR e ,
followed by an optionally signed integer.
.TP
.B [
Indicates a string that is not to be delimited by space characters.
The left bracket is followed by a set of characters and a right
bracket; the characters between the brackets define a set
of characters making up the string.
If the first character
is not a caret
.RB ( \|^\| ),
the input field
consists of all characters up to the first character that is not in the set between
the brackets; if the first character
after the left bracket is
a
.BR ^ ,
the input field consists of all characters
up to the first character that is in the set of the remaining characters
between the brackets.
The corresponding argument must point to a character array.
.PP
The conversion characters
.BR d ,
.BR o ,
and
.B x
may be capitalized and/or preceded
by
.B l
to indicate that a pointer to
.B long
rather than to
.B int
is in the argument list.
Similarly, the conversion characters
.B e
and
.B f
may be capitalized and/or
preceded by
.B l
to indicate that a pointer to
.B double
rather than to
.B float
is in the argument list.
The character
.B h
will, some time in the future, indicate
.B short
data items.
.PP
.I Scanf\^
conversion terminates at
.SM
EOF,
at the end of the control string,
or when an input character conflicts with
the control string.
.I 
In the latter case, the offending character
is left unread in the input stream.
.R
This is very important to remember, because subtle
errors can occur when not taking this into account.
.PP
.I Scanf\^
returns the number of successfully matched
and assigned input items; this number can be zero
in the event of an early conflict between an input
character and the control string.
If the input ends before the first conflict or conversion,
.SM
EOF
is returned.
.SH Examples
The call:
.PP
.RS
int \|i; \|float \|x; \|char \|name[50];
.br
scanf \|("%d%f%s", \|&i, \|&x, \|name);
.RE
.PP
with the input line:
.PP
.RS
25 \|54.32E\(mi1 \|thompson
.RE
.PP
will assign to
.I i\^
the value
.BR 25 ,
to
.I x\^
the value
.BR 5.432 ,
and
.I name\^
will contain
.BR thompson\e0 .
Or:
.PP
.RS
int \|i; \|float \|x; \|char \|name[50];
.br
scanf \|("%2d%f%\(**d%[1234567890]", \|&i, \|&x, \|name);
.RE
.PP
with input:
.PP
.RS
56789 \|0123 \|56a72
.RE
.PP
will assign
.B 56
to
.IR i ,
.B 789.0
to
.IR x ,
skip
.BR 0123 ,
and place the string
.B 56\e0
in
.IR name .
The next call to
.I getchar\^
(see
.IR getc (S))
will return
.BR a .
.SH "See Also"
atof(S),
getc(S),
printf(S)
.SH Diagnostics
These
functions return
.SM
EOF
on end of input
and a short count for missing or illegal data items.
.SH Notes
The success of literal matches and suppressed
assignments is not directly
determinable.
.PP
Trailing whitespace (including a newline)
is left unread unless matched in the control string.
