.\" bm# 0000002385
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH SDENTER S 
.SH Name
sdenter, sdleave \- Synchronizes access to a shared data segment.
.SH Syntax
.B #include <sd.h>
.sp 1
.B int sdenter(addr,flags)
.br
.B char *addr;
.br
.B int flags;
.PP
.B int sdleave(addr)
.br
.B char *addr;
.SH Description
.I Sdenter 
is used to indicate that the current process is about to
access the contents of a shared data segment.
The actions performed depend on the value of 
.I flags.
.I Flags 
values are formed by OR-ing together entries from the following list:
.TP 14
.SM
SD_NOWAIT
If another process has called 
.I sdenter
but not
.I sdleave
for the indicated segment, and the segment was not created with the
\s-1SD_UNLOCK\s+1 flag set, return an error instead of waiting for
the segment to become free.
.TP 14
.SM
SD_RDONLY
Indicates that the process wants only to read the data, not modify it.
.PP
.I Sdleave 
is used to indicate that the current process is done modifying
the contents of a shared data segment.
.PP
Only changes made between invocatations of 
.I sdenter
and 
.I sdleave
are guaranteed to be reflected in other processes.
.I Sdenter
and
.I sdleave
are very fast; consequently, it is recommended that they be called
frequently rather than leave 
.I sdenter
in effect for any period of time.
In particular, system calls should be avoided between 
.I sdenter
and
.I sdleave
calls.
.PP
The
.I fork
system call is forbidden between calls to 
.I sdenter
and 
.I sdleave
if the segment was created without the \s-1SD_UNLOCK\s+1 flag.
.br
.ne 2i
.SH "Return Value"
Successful calls return 0.  
Unsuccessful calls return -1, and
.I errno
is set to indicate the error.
.SH "See Also"
sdget(S),
sdgetv(S)
