.\" bm# 0000002373
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH SSIGNAL S
.SH Name
ssignal, gsignal \- Implements software signals.
.SH Syntax
.B #include <signal.h>
.PP
.B int (\(**ssignal (sig, action))( )
.br
.B int sig, (\(**action)( );
.PP
.B int gsignal (sig)
.br
.B int sig;
.SH Description
.I Ssignal\^
and
.I gsignal\^
implement a software facility similar to
.IR signal (S).
This facility is used by the standard C library 
to enable the user to indicate
the disposition of error conditions, 
and is also made available to the user for his own purposes.
.PP
Software signals made available to users are associated
with integers in the inclusive
range 1 through 15. An
.I action\^
for a software signal is
.I established\^
by a call to
.IR ssignal ,
and a software signal is
.I raised\^
by a call to
.IR gsignal .
Raising a software signal causes the action established for that signal
to be
.IR taken .
.PP
The first argument to
.I ssignal\^
is a number identifying the type of signal for which an action is to be
established. The second argument defines the action; it is either the
name of a (user defined)
.I action function\^
or one of the manifest constants
.SM
SIG_DFL
(default) or
.SM
SIG_IGN
(ignore).
.I Ssignal\^
returns the action previously established for that signal type; if no
action has been established or the signal number is illegal,
.I ssignal\^
returns
.SM
SIG_DFL.
.PP
.I Gsignal\^
raises the signal identified by its argument,
.IR sig :
.RS 5
.PP
If an action function has been established for
.IR sig ,
then that action is reset to
.SM
SIG_DFL
and the action function is entered with argument
.IR sig .
.I Gsignal\^
returns the value returned to it by the action function.
.PP
If the action for
.I sig\^
is
.SM
SIG_IGN ,
.I gsignal\^
returns the value 1 and takes no other action.
.PP
If the action for
.I sig\^
is
.SM
SIG_DFL ,
.I gsignal\^
returns the value 0 and takes no other action.
.PP
If
.I sig\^
has an illegal value or no action was ever specified for
.IR sig ,
.I gsignal\^
returns the value 0 and takes no other action.
.RE
.SH Notes
There are some additional signals with numbers 
outside the range 1 through 15
that are used by the standard C library to indicate error conditions.
Thus, some signal numbers outside 
the range 1 through 15 are legal, although
their use may interfere with the operation of the standard C library.
