.\" bm# 0000002372
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH STAT S
.SH Name
stat, fstat \- Gets file status.
.SH Syntax
.B #include <sys/types.h>
.br
.B #include <sys/stat.h>
.PP
.B int stat (path, buf)
.br
.B char \(**path;
.br
.B struct stat \(**buf;
.PP
.B int fstat (fildes, buf)
.br
.B int fildes;
.br
.B struct stat \(**buf;
.SH Description
.I Path\^
points to a
pathname
naming a file.
Read, write or execute permission of the named file is not required,
but all directories
listed in the
pathname
leading to the file must be searchable.
.I Stat\^
obtains information about the named file.
.PP
Similarly,
.I fstat\^
obtains information about an open file
known by the
file descriptor
.IR fildes ,
obtained from a successful
.IR open ,
.IR creat ,
.IR dup ,
.IR fcntl ,
or
.I pipe\^
system call.
.PP
.I Buf\^
is a pointer to a
.I stat\^
structure into which information
is placed concerning the file.
.PP
The contents of the structure pointed to by
.I buf\^
include the following members:
.sp
.RS
.ta 8n 20n
ushort	st_mode;	/\(** File mode; see
.IR mknod (S)
\(**/
.br
ino_t	st_ino;	/\(** Inode number \(**/
.br
dev_t	st_dev;	/\(**
.SM ID
of device containing \(**/
.br
		/\(** a directory entry for this file \(**/
.br
dev_t	st_rdev;	/\(**
.SM ID
of device \(**/
.br
		/\(** This entry is defined only for \(**/
.br
		/\(** special files \(**/
.br
short	st_nlink;	/\(** Number of links \(**/
.br
ushort	st_uid;	/\(** User
.SM ID
of the file's owner \(**/
.br
ushort	st_gid;		/\(** Group
.SM ID
of the file's group \(**/
.br
off_t	st_size;	/\(** File size in bytes \(**/
.br
time_t	st_atime;	/\(** Time of last access \(**/
.br
time_t	st_mtime;	/\(** Time of last data modification \(**/
.br
time_t	st_ctime;	/\(** Time of last file status change \(**/
.br
		/\(** Times measured in seconds since \(**/
.br
		/\(** 00:00:00
.SM GMT\*S,
Jan. 1, 1970 \(**/
.RE
.DT
.PP
.TP 11
.B st_atime
Time when file data was last accessed.
Changed by the following system calls:
.IR creat (S),
.IR mknod (S),
.IR pipe (S),
.IR utime (S),
and
.IR read (S).
.TP 10
.B st_mtime
Time when data was last modified.
Changed by the following system calls:
.IR creat (S),
.IR mknod (S),
.IR pipe (S),
.IR utime (S),
and
.IR write (S).
.TP 10
.B st_ctime
Time when file status was last changed.
Changed by the following system calls:
.IR chmod (S),
.IR chown (S),
.IR creat (S),
.IR link (S),
.IR mknod (S),
.IR pipe (S),
.IR utime (S),
and
.IR write (S).
.TP 10
.B st_rdev
Device indentification. In the case of block and character
special files this contains the device major and minor numbers;
in the case of shared memory and semaphores, it contains
the type code.
The file
.B /usr/include/sys/types.h
contains the macros 
.IR major ()
and 
.IR minor ()
for extracting major and minor numbers from 
.I st_rdev.
See
.B /usr/include/sys/stat.h
for the semaphore and shared memory type code values 
.SM S_INSEM 
and 
.SM S_INSHD.
.PP
.I Stat\^
will fail if one or more of the following are true:
.IP
A component of the path prefix is not a directory.
.SM
\%[ENOTDIR]
.IP
The named file does not exist.
.SM
\%[ENOENT]
.IP
Search permission is denied for a component of the
path prefix.
.SM
\%[EACCES]
.IP
.I Buf\^
or
.I path\^
points to an invalid address.
.SM
\%[EFAULT]
.PP
.I Fstat\^
will fail if one or more of the following are true:
.IP
.I Fildes\^
is not a valid open file descriptor.
.SM
\%[EBADF]
.IP
.I Buf\^
points to an invalid address.
.SM
\%[EFAULT]
.SH "Return Value"
Upon successful completion a value of 0 is returned.
Otherwise, a value of \-1 is returned and
.I errno\^
is set to indicate the error.
.SH "See Also"
chmod(S), chown(S), creat(S), link(S), mknod(S), time(S), unlink(S)
