.\" bm# 0000002365
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH TERMCAP S
.SH Name
tgetent, tgetnum, tgetflag, tgetstr, tgoto, tputs \- Performs terminal functions.
.SH Syntax
.nf
.B char PC;
.B char *BC;
.B char *UP;
.B short ospeed;
.PP
.B tgetent(bp, name)
.B char *bp, *name;
.PP
.B tgetnum(id)
.B char *id;
.PP
.B tgetflag(id)
.B char *id;
.PP
.B char *tgetstr (id, area)
.B char *id, **area;
.PP
.B char *tgoto (cm, destcol, destline)
.B char *cm;
.PP
.B tputs(cp, affcnt, outc)
.B register char *cp;
.B int affcnt;
.B int (*outc)();
.fi
.SH Description
These functions extract and use capabilities from the terminal capability data
base
.IR termcap (M).
These are low level routines;
see
.IR curses (S)
for a higher level package.
.PP
.I Tgetent
extracts the entry for terminal
.I name
into the buffer at
.I bp.
.I Bp
should be a character buffer of size
1024 and must be retained through all subsequent calls
to
.I tgetnum,
.I tgetflag,
and
.I tgetstr.
.I Tgetent
returns \-1 if it cannot open the
.I termcap
file, 0 if the terminal name given does not have an entry,
and 1 if all goes well.
It will look in the environment for a 
.SM TERMCAP 
variable.
If found, and the value does not begin with a slash,
and the terminal type
.B name
is the same as the environment string 
.SM TERM,
the 
.SM TERMCAP 
string is used instead of reading the termcap file.
If it does begin with a slash, 
the string is used as a pathname rather than
.I /etc/termcap.
This can speed up entry into programs that call
.IR tgetent ,
as well as to help debug new terminal descriptions
or to make one for your terminal if you can't write the file
.I /etc/termcap.
.PP
.I Tgetnum
gets the numeric value of capability
.I id,
returning \-1 if is not given for the terminal.
.I Tgetflag
returns 1 if the specified capability is present in
the terminal's entry, 0 if it is not.
.I Tgetstr
gets the string value of capability
.I id,
placing it in the buffer at
.I area,
advancing the
.I area
pointer.
It decodes the abbreviations for this field described in
.IR termcap (M),
except for cursor addressing and padding information.
.PP
.I Tgoto
returns a cursor addressing string decoded from
.I cm
to go to column
.I destcol
in line
.I destline.
It uses the external variables
.SM UP
(from the \fBup\fR capability)
and
.SM BC
(if \fBbc\fR is given rather than \fBbs\fR)
if necessary to avoid placing \fB\en\fR, 
.SM CNTRL-D
or 
.SM NULL
in the returned string.
(Programs which call 
.I tgoto 
should be sure to turn off the 
.SM TAB3 
bit
(see
.IR tty\^ (M)),
since 
.I tgoto 
may now output a tab.
Note that programs using termcap should in general turn off 
.SM TAB3
anyway since some terminals use 
.SM CNTRL-I 
for other functions,
such as nondestructive space.)
If a \fB%\fR sequence is given which is not understood, then
.I tgoto
returns 
.SM ``OOPS''.
.PP
.I Tputs
decodes the leading padding information of the string
.I cp;
.I affcnt
gives the number of lines affected by the operation, or 1 if this is
not applicable,
.I outc
is a routine which is called with each character in turn.
The external variable
.I ospeed
should contain the output speed of the terminal as encoded by
.IR stty (C).
The external variable
.SM PC
should contain a pad character 
to be used (from the 
.B pc 
capability)
if a 
.SM NULL 
is inappropriate.
.SH Files
.ta \w'/usr/lib/libtermcap.a  'u
/usr/lib/libtermcap.a	\-ltermcap library
.br
/etc/termcap	data base
.DT
.SH "See Also"
curses(S), termcap(M), tty(M)
.SH Credit
This utility was developed 
at the University of California at Berkeley 
and is used with permission.
.SH Notes
These routines can be linked by using the 
linker option
.RB \-l termcap.
