.\" bm# 0000002350
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH WAIT S 
.SH Name
wait \- Waits for a child process to stop or terminate.
.SH Syntax
.B int wait (stat_loc)
.br
.B int \(**stat_loc;
.PP
.B int wait ((int \(**)0)
.SH Description
.I Wait\^
suspends the calling process 
until it receives a signal that is to be caught
(see
.IR signal (S)),
or until any one of the calling process' child
processes stops in a trace mode (see
.IR ptrace (S))
or terminates.
If a child process stopped or terminated prior to the call on
.IR wait ,
return is immediate.
.PP
If
.I stat_loc\^
(taken as an integer) is nonzero, 16 bits of information 
called ``status''
are stored in the low-order 16 bits of the location pointed to by
.IR stat_loc .
.I Status\^
can be used to differentiate between stopped 
and terminated child processes and
if the child process terminated, status identifies 
the cause of termination
and passes useful information to the parent. This is accomplished in the
following manner:
.IP
If the child process stopped, the high-order 8 bits 
of status will be zero and
the low-order 8 bits will be set equal to 0177.
.IP
If the child process terminated due to an
.I exit\^
call, the low-order 8 bits of status will be 
zero and the high-order 8 bits
will contain the low-order 8 bits of the argument 
that the child process
passed to
.IR exit ;
see
.IR exit (S).
.IP
If the child process terminated due to a signal, the high-order 8 bits
of status will be zero and the low-order 8 bits will contain the number of the
signal that caused the termination. In addition, if the low-order seventh bit
(i.e., bit 200) is set, a ``core image'' will have been produced; see
.IR signal (S).
.PP
If a parent process terminates without waiting for its child processes
to terminate, the parent process
.SM ID
of each child process is set to 1. This means the initialization process
inherits the child processes; see
.IR intro (S).
.PP
.ne 2i
.I Wait\^
will fail and return immediately if one or more of the following are true:
.IP
The calling process has no existing unwaited-for child processes.
.SM
\%[ECHILD]
.IP
.I Stat_loc\^
points to an illegal address.
.SM
\%[EFAULT]
.SH "Return Value"
If
.I wait\^
returns due to the receipt of a signal, a value of \-1 is returned
to the calling process and
.I errno\^
is set to
.SM EINTR.
If
.I wait\^
returns due to a stopped or terminated child process, the process
.SM ID
of the child is returned to the calling process.
Otherwise, a value of \-1 is returned and
.I errno\^
is set to indicate the error.
.SH "See Also"
exec(S), exit(S), fork(S), pause(S), signal(S)
.SH Warning
See
.SM
.I Warning\^
in
.IR signal (S).
