.\" bm# 0000002412
.\" typ N
.\" ver generic
.\" mod generic
.\"
.ds mc 
.ds rv Revision 1
.TH MALLOC S 
.SH Name
malloc, free, realloc, calloc \- Allocates main memory.
.SH Syntax
.B char \(**malloc (size)
.B unsigned size;
.PP
.B free (ptr)
.br
.B char \(**ptr;
.PP
.B char \(**realloc (ptr, size)
.br
.B char \(**ptr;
.br
.B unsigned size;
.PP
.B char \(**calloc (nelem, elsize)
.br
.B unsigned elem, elsize;
.SH Description
.I Malloc\^
and
.I free\^
provide a simple general-purpose memory allocation package.
.I Malloc\^
returns a pointer to a block of at least
.I size\^
bytes beginning on a word boundary.
.PP
The argument to
.I free\^
is a pointer to a block previously allocated by
.IR malloc ;
this space is made available for further allocation,
but its contents are left undisturbed.
.PP
Needless to say, grave disorder will result if the space
assigned by
.I malloc\^
is overrun or if some random number is handed to
.IR free .
.PP
.I Malloc\^
allocates the first contiguous reach of
free space
found in a circular search from the last 
block allocated or freed,
coalescing adjacent free blocks as it searches.
It calls
.I sbrk\^
(see
.IR sbrk (S))
to get more memory from the system when there is no
suitable space already free.
.PP
.I Realloc\^
changes the size of the block pointed to by
.I ptr\^
to
.I size\^
bytes and returns a pointer to the (possibly moved)
block.
The contents will be unchanged up to the
lesser of the new and old sizes.
.PP
.I Realloc\^
also works if
.I ptr\^
points to a block freed since the last call of
.IR malloc ,
.IR realloc ,
or
.IR calloc ;
thus sequences of
.IR free ,
.I malloc\^
and
.I realloc\^
can exploit the search strategy of
.I malloc\^
to do storage compaction.
.PP
.I Calloc\^
allocates space for
an array of
.I nelem\^
elements of size
.IR elsize .
The space is initialized to zeros.
.PP
Each of the allocation routines returns a pointer
to space suitably aligned (after possible pointer coercion)
for storage of any type of object.
.SH Diagnostics
.IR Malloc ,
.I realloc\^
and
.I calloc\^
return a null pointer (0) if there is no available memory
or if the area has been detectably corrupted by storing outside the bounds
of a block.
When
.I realloc\^
returns 0,
the block
pointed to by
.I ptr\^
may be destroyed.
